@@ -4,7 +4,7 @@ use warnings;
 use 5.010;
 use Brickyard::Accessor new => 1, rw => [qw(brickyard)];
 use Brickyard 1.111750;
-our $VERSION = '1.112001';
+our $VERSION = '1.12';
 
 sub run_with_config {
     my $file = $_[1];
@@ -68,14 +68,19 @@ my $DB_eval = \&DB::eval;
 };
 1;
 
+__END__
+
 =pod
 
-=for test_synopsis 1;
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
-DB::Pluggable - Add plugin support for the Perl debugger
+DB::Pluggable
+
+=head1 VERSION
+
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -93,7 +98,7 @@ DB::Pluggable - Add plugin support for the Perl debugger
     [DataPrinter]
     EOINI
 
-Then:
+    Then:
 
     $ perl -d foo.pl
 
@@ -108,6 +113,12 @@ that invokes the plugin mechanism.
 Plugins should live in the C<DB::Pluggable::Plugin::> namespace, like
 L<DB::Pluggable::Plugin::BreakOnTestNumber> does.
 
+=head1 NAME
+
+DB::Pluggable - Add plugin support for the Perl debugger
+
+=for test_synopsis BEGIN { die "SKIP: Skipping the config file portion of synopsis...\n" };
+
 =head1 METHODS
 
 =head2 run_with_config
@@ -172,11 +183,10 @@ introduced to make your command work.
 
 =head1 AUTHOR
 
-The following person is the author of all the files provided in
-this distribution unless explicitly noted otherwise.
-
 Marcel Gruenauer <marcel@cpan.org>
 
+Currently maintained by Keith Carangelo <mail@kcaran.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 The following copyright notice applies to all the files provided in
@@ -187,3 +197,26 @@ This software is copyright (c) 2008-2011 by Marcel Gruenauer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Keith Carangelo <mail@kcaran.com>
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Marcel Gruenauer <marcel@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
