@@ -9,7 +9,7 @@ with qw(
   DB::Pluggable::Role::Initializer
   DB::Pluggable::Role::WatchFunction
 );
-our $VERSION = '1.112001';
+our $VERSION = '1.12';
 
 sub initialize {
     @DB::testbreak = ();
@@ -64,16 +64,19 @@ sub watchfunction {
 }
 1;
 
+__END__
+
 =pod
 
-=for stopwords watchfunction
-
-=for test_synopsis 1;
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
-DB::Pluggable::Plugin::BreakOnTestNumber - Debugger plugin to break on Test::Builder-based tests
+DB::Pluggable::Plugin::BreakOnTestNumber
+
+=head1 VERSION
+
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -103,6 +106,15 @@ breakpoints - with the ability to stop at a specific test number. Andy
 Armstrong had the idea and wrote the original code, see
 L<http://use.perl.org/~AndyArmstrong/journal/35792>.
 
+=for stopwords watchfunction
+
+=for test_synopsis 1;
+__END__
+
+=head1 NAME
+
+DB::Pluggable::Plugin::BreakOnTestNumber - Debugger plugin to break on Test::Builder-based tests
+
 =head1 METHODS
 
 =head2 initialize
@@ -124,3 +136,26 @@ this plugin will break C<Test::Builder> when using threads.
 
 Checks the current test number from L<Test::Builder> and instructs the
 debugger to stop if an appropriate test number has been reached.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Keith Carangelo <mail@kcaran.com>
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Marcel Gruenauer <marcel@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
