@@ -5,7 +5,7 @@ use 5.010;
 use Brickyard::Accessor rw => [qw(type ifenv)];
 use Role::Basic;
 with qw(DB::Pluggable::Role::AfterInit);
-our $VERSION = '1.112001';
+our $VERSION = '1.12';
 
 sub afterinit {
     my $self = shift;
@@ -21,16 +21,19 @@ sub afterinit {
 }
 1;
 
+__END__
+
 =pod
 
-=for stopwords typeahead afterinit
-
-=for test_synopsis 1;
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
-DB::Pluggable::Plugin::TypeAhead - Debugger plugin to add type-ahead
+DB::Pluggable::Plugin::TypeAhead
+
+=head1 VERSION
+
+version 1.12
 
 =head1 SYNOPSIS
 
@@ -65,8 +68,40 @@ typeahead, you would run your program like this:
 The inspiration for this plugin came from Ovid's blog post at
 L<http://blogs.perl.org/users/ovid/2010/02/easier-test-debugging.html>.
 
+=for stopwords typeahead afterinit
+
+=for test_synopsis 1;
+__END__
+
+=head1 NAME
+
+DB::Pluggable::Plugin::TypeAhead - Debugger plugin to add type-ahead
+
 =head1 METHODS
 
 =head2 afterinit
 
 Pushes the commands to the debugger's typeahead.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Keith Carangelo <mail@kcaran.com>
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Marcel Gruenauer <marcel@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
